summaryrefslogtreecommitdiff
path: root/json-glib/json-builder.c
diff options
context:
space:
mode:
Diffstat (limited to 'json-glib/json-builder.c')
-rw-r--r--json-glib/json-builder.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/json-glib/json-builder.c b/json-glib/json-builder.c
index 6531b0c..66a5796 100644
--- a/json-glib/json-builder.c
+++ b/json-glib/json-builder.c
@@ -125,7 +125,7 @@ json_builder_free_all_state (JsonBuilder *builder)
if (builder->priv->root)
{
- json_node_free (builder->priv->root);
+ json_node_unref (builder->priv->root);
builder->priv->root = NULL;
}
}
@@ -272,7 +272,7 @@ json_builder_new_immutable (void)
* (ie: all opened objects, object members and arrays are being closed).
*
* Return value: (transfer full): the #JsonNode, or %NULL if the build is not complete.
* Free the returned value with json_node_free().
*/
JsonNode *
json_builder_get_root (JsonBuilder *builder)
@@ -272,7 +272,7 @@ json_builder_new_immutable (void)
*
* Return value: (transfer full): the #JsonNode, or %NULL if the build is not complete.
- * Free the returned value with json_node_free().
+ * Free the returned value with json_node_unref().
*/
JsonNode *